@@ -172,7 +172,7 @@ class SetupReproEnv(Subcommand):
         if re.match(r"(\d+\.\d+)", version):
             # If the cmdline version is already a semvar, just use that.
             return version
-        elif evg_project_id == "mongodb-mongo-master":
+        elif evg_project_id in ("mongodb-mongo-master", "mongodb-mongo-master-nightly"):
             # If the version is not a semvar and the project is the master waterfall,
             # we can't add a suffix.
             return ""
