@@ -4,7 +4,7 @@ import pathlib
 from typing import List, Optional
 
 import structlog
-from evergreen import RetryingEvergreenApi, Version
+from evergreen import RetryingEvergreenApi, Task, Version
 from requests import HTTPError
 
 from db_contrib_tool.config import SETUP_REPRO_ENV_CONFIG
@@ -134,6 +134,11 @@ def get_evergreen_versions(evg_api, evg_project):
     return evg_api.versions_by_project(evg_project)
 
 
+def get_evergreen_task(evg_api: RetryingEvergreenApi, task_id: str) -> Task:
+    """Return evergreen task by evergreen task id."""
+    return evg_api.task_by_id(task_id)
+
+
 def get_compile_artifact_urls(evg_api, evg_version, buildvariant_name, ignore_failed_push=False):
     """Return compile urls from buildvariant in Evergreen version."""
     try:
